.. _api_reference/data-models-inspectors-extension:

Extension hookspec
============================

.. automodule:: sdgx.data_models.inspectors.extension
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
   :private-members:
